==> kube-integration-1.1.11.tgz: package/lib/kube-native/pod/pod.js <==
'use strict';

const _          = require('lodash');
const BaseEntity = require('./../entity.base');

class Pod extends BaseEntity {

    getName() {
        return _.get(this._getData(), 'metadata.name');
    }

    getNamespace() {
        return _.get(this._getData(), 'metadata.namespace');
    }

    getContainers(){
        const pathToContainers = 'spec.containers';
        const pathToContainerStauts = 'status.containerStatuses';
        const containerSelectedProps = [
            'name',
            'image',
            'resources',
            'ports',
        ];
        return _.get(this._getData(), pathToContainers, [])
            .map((container) => _.merge(_.pick(container, containerSelectedProps), {
                status: _.filter(_.get(this._getData(), pathToContainerStauts, []),
                containerStatus => containerStatus.name === container.name)
            }));
    }

    getImages(){
        return _.chain(this._getData())
            .get('status.containerStatuses', [])
            .map(container => {
                const imageId = _.get(container, 'imageID', '');
                return {
                    id: imageId.substring(imageId.lastIndexOf(':') + 1 ),
                    name: _.get(container, 'image', ''),
                }
            })
            .compact()
            .value();
    }


    getStartTime(){
        return _.get(this._getData(), 'status.startTime');
    }

    getBasicData() {
        return {
            name: this.getName(),
            status: this.getStatus(),
            namespace: this.getNamespace(),
            selector: this.getSelector(),
        }
    }

}

module.exports = Pod;

==> kube-integration-1.1.12.tgz: package/lib/kube-native/pod/pod.js <==
'use strict';

const _          = require('lodash');
const BaseEntity = require('./../entity.base');

class Pod extends BaseEntity {

    getName() {
        return _.get(this._getData(), 'metadata.name');
    }

    getNamespace() {
        return _.get(this._getData(), 'metadata.namespace');
    }

    getContainers(){
        const pathToContainers = 'spec.containers';
        const pathToContainerStauts = 'status.containerStatuses';
        const containerSelectedProps = [
            'name',
            'image',
            'resources',
            'ports',
        ];
        return _.get(this._getData(), pathToContainers, [])
            .map((container) => _.merge(_.pick(container, containerSelectedProps), {
                status: _.filter(_.get(this._getData(), pathToContainerStauts, []),
                containerStatus => containerStatus.name === container.name)
            }));
    }

    getImages(){
        return _.chain(this._getData())
            .get('status.containerStatuses', [])
            .map(container => {
                const imageId = _.get(container, 'imageID', '');
                return {
                    imageID: imageId.substring(imageId.lastIndexOf(':') + 1 ),
                    name: _.get(container, 'image', ''),
                }
            })
            .compact()
            .value();
    }


    getStartTime(){
        return _.get(this._getData(), 'status.startTime');
    }

    getBasicData() {
        return {
            name: this.getName(),
            status: this.getStatus(),
            namespace: this.getNamespace(),
            selector: this.getSelector(),
        }
    }

}

module.exports = Pod;
